@@ -18,8 +18,7 @@ readability has been sacrificed, specifically in the C code.
 
 L.A.Cosmic = LAplacian Cosmic ray detection
 
-If you use this code, please consider adding this repository address in a
-footnote: https://github.com/astropy/astroscrappy.
+If you use this code, please cite the Zendo DOI: https://zenodo.org/record/1482019
 
 Please cite the original paper which can be found at:
 http://www.astro.yale.edu/dokkum/lacosmic/
@@ -61,12 +60,10 @@ scipy.
 # Affiliated packages may add whatever they like to this file, but
 # should keep this content at the top.
 # ----------------------------------------------------------------------------
-from ._astropy_init import *
+from ._astropy_init import *  # noqa
 # ----------------------------------------------------------------------------
 
-# For egg_info test builds to pass, put package imports here.
-if not _ASTROPY_SETUP_:
-    from .astroscrappy import *
-    from .utils import *
+from .astroscrappy import *  # noqa
+from .utils import *  # noqa
 
-__all__ = ['detect_cosmics']
+__all__ = ['detect_cosmics']  # noqa
